@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Sah::Schemas;
 
-our $DATE = '2016-08-04'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2016-12-26'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -209,7 +209,7 @@ sub munge_files {
 
                     "=head1 DESCRIPTION\n\n",
                     "This module is automatically generated by ".__PACKAGE__." during distribution build.\n\n",
-                    "A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema wihout having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.\n\n",
+                    "A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema without having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.\n\n",
                 ),
             );
             $self->log(["Creating file %s", $rname]);
@@ -251,7 +251,7 @@ Dist::Zilla::Plugin::Sah::Schemas - Plugin to use when building Sah-Schemas-* di
 
 =head1 VERSION
 
-This document describes version 0.004 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2016-08-04.
+This document describes version 0.005 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2016-12-26.
 
 =head1 SYNOPSIS
 
@@ -284,7 +284,7 @@ Otherwise, the build is aborted.
 
 =item * Produce pre-resolved editions of schemas into C<lib/Sah/SchemaR/*>
 
-These are useful if a client wants to lookup the base type of a schema wihout
+These are useful if a client wants to lookup the base type of a schema without
 having to do any extra resolving. Currently L<Perinci::Sub::Complete> uses this
 to reduce startup overhead when doing tab completion.
 
